/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
@namespace html url("http://www.w3.org/1999/xhtml");

.editContactPanel_rowLabel {
  text-align: end;
}

#editContactPanel {
  -moz-appearance: none;
  background-color: #EDEDED;
  border: 1px solid rgba(255,255,255,0.15);
  border-radius: 5px;
  border-top-left-radius: 0px;
  padding: 10px 8px 6px;
  margin-top: 4px;
  box-shadow: 0 0 0 1px rgba(255, 255, 255, .5) inset,
              0 1px 0 rgba(255, 255, 255, .05) inset,
              0 0 0 1px rgba(0, 0, 0, .25);
  color: #333;
}

#editContactPanel > #editContactContent {
  margin-top: 6px;
}

#editContactPanelIcon {
  list-style-image: url("chrome://messenger/skin/starred48.png");
  width: 48px;
  height: 48px;
  min-height: 48px;
}

#editContactPanelTitle {
  font-size: 130%;
  font-weight: bold;
  margin-top: 8px;
  margin-bottom: 2px;
  -moz-margin-start: 9px;
  -moz-margin-end: 12px;
}

#editContactEmail {
  min-width: 20em;
}

/**** HUD style buttons ****/

#editContactPanel > hbox > button,
#editContactPanel > hbox > vbox > hbox > button,
#editContactPanel > #editContactPanelBottomButtons > button {
  -moz-appearance: none;
  color: #434343;
  border-radius: 4px;
  border: 1px solid #B5B5B5;
  background: linear-gradient(#FFFFFF, #F2F2F2);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.8),
              inset 0 0 1px rgba(255, 255, 255, 0.25),
              0 1px rgba(255, 255, 255, 0.3);
  background-clip: padding-box;
  background-origin: padding-box;
  padding: 2px 6px;
  margin: 6px;
  min-width: 79px;
  min-height: 22px;
}

#editContactPanel > hbox > button:hover:active,
#editContactPanel > hbox > vbox > hbox > button:hover:active,
#editContactPanel > #editContactPanelBottomButtons > button:hover:active {
  box-shadow: inset 0 1px 4px -3px #000, 0 1px rgba(255, 255, 255, 0.3);
}

#editContactPanel > hbox > button:focus,
#editContactPanel > hbox > vbox > hbox > button:focus,
#editContactPanel > #editContactPanelBottomButtons > button:focus {
  outline: 2px solid -moz-mac-focusring;
  outline-offset: -2px;
  -moz-outline-radius: 100%;
}

.editContactTextbox {
  -moz-appearance: none !important;
  cursor: text;
  margin: 2px 6px;
  background: linear-gradient(#FAFAFA, #FFFFFF);
  background-clip: padding-box;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.3);
  box-shadow: inset 0 1px 1px 1px rgba(0, 0, 0, 0.05),
              0 1px rgba(255, 255, 255, 0.3);
  padding: 3px 6px;
}

.editContactTextbox[readonly="true"] {
  -moz-appearance: none;
  border-color: transparent;
  background: #EDEDED;
  box-shadow: none;
}

.editContactTextbox[focused="true"] {
  border-color: -moz-mac-focusring !important;
  box-shadow: 0 0 1px -moz-mac-focusring inset,
              0 0 4px 1px -moz-mac-focusring,
              0 0 1.5px 1px -moz-mac-focusring;
}

.editContactTextbox[focused="true"][readonly="true"] {
  border-color: transparent !important;
  box-shadow: none;
}

#editContactAddressBookList {
  -moz-appearance: none;
  color: #434343;
  border-radius: 4px;
  border: 1px solid #B5B5B5;
  background: linear-gradient(#FFFFFF, #F2F2F2);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.8),
              inset 0 0 1px rgba(255, 255, 255, 0.25),
              0 1px rgba(255, 255, 255, 0.3);
  background-clip: padding-box;
  background-origin: padding-box;
  padding: 2px 6px;
  margin: 0 6px;
}

#editContactAddressBookList:focus {
  outline: 2px solid -moz-mac-focusring;
  outline-offset: -2px;
  -moz-outline-radius: 5px;
}

#editContactAddressBookList[disabled="true"] {
  color: GrayText !important;
}

#editContactAddressBookList > .menulist-dropmarker {
  -moz-appearance: none;
  display: -moz-box;
  background-color: transparent;
  border: 0;
  margin: 0;
  padding: 0;
  -moz-padding-end: 4px;
  width: 7px;
}

#editContactAddressBookList > .menulist-dropmarker > .dropmarker-icon {
  list-style-image: url("chrome://global/skin/icons/panel-dropmarker.png");
}

#contactMoveDisabledText {
  margin-left: 8px;
  width: 20em;
}
