/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package org.ietf.ldap;

/**
 * The <CODE>LDAPTraceWriter</CODE> interface enables logging of LDAP
 * trace messages in environments where an OutputStream can not be used.
 * <P>
 * The interface is primarily meant for integrating LDAP tracing with the
 * servlet log facility:
 * <P>
 * <PRE>
 *     servletCtx = config.getServletContext();
 *     ...
 *     LDAPConnection ld = new LDAPConnection();
 *     ld.setProperty(ld.TRACE_PROPERTY, 
 *            new LDAPTraceWriter() { 
 *                public void write (String msg) {
 *                    servletCtx.log(msg);
 *                }
 *            });
 * <PRE>
 * <P>
 *
 * @version 1.0
 * @see org.ietf.ldap.LDAPConnection#setProperty(java.lang.String, java.lang.Object)
 */
public interface LDAPTraceWriter {

     /**
     * Writes an LDAP trace message.
     * 
     * @param msg An incoming or outgoing LDAP message
     *
     * @version 1.0
     * @see org.ietf.ldap.LDAPConnection#setProperty(java.lang.String, java.lang.Object)
     */
    public void write (String msg);

}
